@@ -1,6 +1,6 @@
 /*****************************************************************************
  *  CP2K: A general program to perform molecular dynamics simulations        *
- *  Copyright (C) 2000 - 2014 the CP2K developers group                      *
+ *  Copyright (C) 2000 - 2015  CP2K developers group                         *
  *****************************************************************************/
 
 #ifndef ACC_OPENCL_DEV_H
@@ -20,13 +20,13 @@ typedef struct {
 } acc_opencl_dev_type;
 
 // global (per MPI) device information
-extern uint acc_opencl_ndevices;
+extern cl_uint acc_opencl_ndevices;
 extern acc_opencl_dev_type *acc_opencl_devices;
 extern acc_opencl_dev_type *acc_opencl_my_device;
 
 // global configuration information
-static uint acc_opencl_ndevices_configured = 0;
-static uint acc_opencl_set_device_configured = 0;
+static cl_uint acc_opencl_ndevices_configured = 0;
+static cl_uint acc_opencl_set_device_configured = 0;
 
 #endif
 #endif
