@@ -46,14 +46,12 @@
 !> \param matrix ...
 !> \param vectors ...
 !> \param arnoldi_data ...
-!> \param error ...
 ! *****************************************************************************
 
-  SUBROUTINE arnoldi_init_d (matrix, vectors, arnoldi_data, error)
+  SUBROUTINE arnoldi_init_d (matrix, vectors, arnoldi_data)
     TYPE(dbcsr_obj_type_p), DIMENSION(:)     :: matrix
     TYPE(m_x_v_vectors)                      :: vectors
     TYPE(dbcsr_arnoldi_data)                 :: arnoldi_data
-    TYPE(dbcsr_error_type), INTENT(inout)    :: error
 
     CHARACTER(LEN=*), PARAMETER :: routineN = 'arnoldi_init_d', &
       routineP = moduleN//':'//routineN
@@ -103,7 +101,8 @@
     ! compute the vector norm of the random vectorm, get it real valued as well (rnorm)
     CALL compute_norms_d(v_vec, norm, rnorm, control%pcol_group)
 
-    CALL dbcsr_scale(vectors%input_vec, REAL(1.0, real_8)/rnorm, error=error)
+    IF (rnorm==0) rnorm=1 ! catch case where this rank has no actual data
+    CALL dbcsr_scale(vectors%input_vec, REAL(1.0, real_8)/rnorm)
 
     ! Everything prepared, initialize the Arnoldi iteration
     CALL transfer_dbcsr_to_local_array_d(vectors%input_vec, v_vec, nrow_local, control%local_comp)
@@ -111,8 +110,8 @@
     ! This permits to compute the subspace of a matrix which is a product of multiple matrices
     DO i=1, SIZE(matrix)
        CALL dbcsr_matrix_colvec_multiply(matrix(i)%matrix, vectors%input_vec, vectors%result_vec, 1.0_real_8, &
-                                        0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec, error)
-       CALL dbcsr_copy(vectors%input_vec, vectors%result_vec, error=error)
+                                        0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec)
+       CALL dbcsr_copy(vectors%input_vec, vectors%result_vec)
     END DO
 
     CALL transfer_dbcsr_to_local_array_d(vectors%result_vec, w_vec, nrow_local, control%local_comp)
@@ -138,12 +137,10 @@
 !>        QR and  gemms can be made linear and a N^2 sacling will be acchieved
 !>        however this already sets the framework but should be used with care
 !> \param arnoldi_data ...
-!> \param error ...
 ! *****************************************************************************
 
-  SUBROUTINE arnoldi_iram_d(arnoldi_data,error)
+  SUBROUTINE arnoldi_iram_d(arnoldi_data)
     TYPE(dbcsr_arnoldi_data)                 :: arnoldi_data
-    TYPE(dbcsr_error_type), INTENT(inout)    :: error
 
     CHARACTER(LEN=*), PARAMETER :: routineN = 'arnoldi_iram_d', &
          routineP = moduleN//':'//routineN
@@ -151,7 +148,7 @@
     TYPE(arnoldi_data_d), POINTER            :: ar_data
     TYPE(arnoldi_control), POINTER                     :: control
     COMPLEX(real_8), DIMENSION(:,:), ALLOCATABLE  :: tmp_mat, safe_mat, Q, tmp_mat1
-    COMPLEX(real_8), DIMENSION(:), ALLOCATABLE    :: work, tau
+    COMPLEX(real_8), DIMENSION(:), ALLOCATABLE    :: work, tau, work_measure
     INTEGER                                   :: msize, lwork, i, j, info, nwant
     REAL(kind=real_8)                          :: beta, sigma
     REAL(kind=real_8),DIMENSION(:,:),ALLOCATABLE :: Qdata
@@ -164,7 +161,7 @@
     nwant=control%nval_out
     ALLOCATE(tmp_mat(msize,msize)); ALLOCATE(safe_mat(msize,msize))
     ALLOCATE(Q(msize,msize)); ALLOCATE(tmp_mat1(msize,msize))
-    ALLOCATE(work(msize**2)); lwork=msize**2
+    ALLOCATE(work_measure(1))
     ALLOCATE(tau(msize)); ALLOCATE(Qdata(msize,msize))
     !make Q identity
     Q=CMPLX(0.0, 0.0, real_8)
@@ -184,6 +181,15 @@
           tmp_mat(j,j)=tmp_mat(j,j)-ar_data%evals(i)
        END DO
        ! Now we repair the damage by QR factorizing
+       lwork=-1
+       CALL zgeqrf(msize,msize,tmp_mat,msize,tau,work_measure,lwork,info)
+       lwork=INT(work_measure(1))
+       IF (ALLOCATED(work)) THEN
+          IF (SIZE(work).LT.lwork) THEN
+             DEALLOCATE(work)
+          ENDIF
+       ENDIF
+       IF (.NOT.ALLOCATED(work)) ALLOCATE(work(lwork))
        CALL zgeqrf(msize,msize,tmp_mat,msize,tau,work,lwork,info)
        ! Ask Lapack to reconstruct Q from its own way of storing data (tmpmat will contain Q)
        CALL zungqr(msize,msize,msize,tmp_mat,msize,tau,work,lwork,info)
@@ -219,7 +225,7 @@
     ! Set the current step to nwant so the subspace build knows where to start
     control%current_step=nwant
     
-    DEALLOCATE(tmp_mat,safe_mat,Q,Qdata,tmp_mat1,work,tau)
+    DEALLOCATE(tmp_mat,safe_mat,Q,Qdata,tmp_mat1,work,tau,work_measure)
     
   END SUBROUTINE arnoldi_iram_d
 
@@ -232,14 +238,11 @@
 !> \param matrix ...
 !> \param vectors ...
 !> \param arnoldi_data ...
-!> \param error ...
 ! *****************************************************************************
-
-  SUBROUTINE build_subspace_d(matrix, vectors, arnoldi_data, error)
+  SUBROUTINE build_subspace_d(matrix, vectors, arnoldi_data)
     TYPE(dbcsr_obj_type_p), DIMENSION(:)     :: matrix
-    TYPE(m_x_v_vectors)                      :: vectors
+    TYPE(m_x_v_vectors), TARGET              :: vectors
     TYPE(dbcsr_arnoldi_data)                 :: arnoldi_data
-    TYPE(dbcsr_error_type), INTENT(inout)    :: error
 
     CHARACTER(LEN=*), PARAMETER :: routineN = 'build_subspace_d', &
          routineP = moduleN//':'//routineN
@@ -247,9 +250,10 @@
     INTEGER                                  :: i, j, ncol_local, nrow_local
     REAL(real_8)                        :: rnorm
     TYPE(arnoldi_control), POINTER           :: control
-    TYPE(arnoldi_data_d), POINTER            :: ar_data
+    TYPE(arnoldi_data_d), POINTER  :: ar_data
     REAL(kind=real_8)                         :: norm
     REAL(kind=real_8), ALLOCATABLE, DIMENSION(:)      :: h_vec, s_vec, v_vec, w_vec
+    TYPE(dbcsr_obj), POINTER                 :: input_vec, result_vec, swap_vec
 
     ar_data=>get_data_d(arnoldi_data)
     control=>get_control(arnoldi_data)
@@ -272,27 +276,32 @@
        IF(control%converged)EXIT
 
        ! transfer normalized residdum to history and its norm to the Hessenberg matrix
+       IF (rnorm==0) rnorm=1 ! catch case where this rank has no actual data
        v_vec(:)=ar_data%f_vec(:)/rnorm; ar_data%local_history(:, j+1)=v_vec(:); ar_data%Hessenberg(j+1, j)=norm
 
-       CALL transfer_local_array_to_dbcsr_d(vectors%input_vec, v_vec, nrow_local, control%local_comp)
+       input_vec=>vectors%input_vec
+       result_vec=>vectors%result_vec
+       CALL transfer_local_array_to_dbcsr_d(input_vec, v_vec, nrow_local, control%local_comp)
  
        ! This permits to compute the subspace of a matrix which is a product of two matrices
        DO i=1, SIZE(matrix)
-          CALL dbcsr_matrix_colvec_multiply(matrix(i)%matrix, vectors%input_vec, vectors%result_vec, 1.0_real_8, &
-                                            0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec, error)
-          CALL dbcsr_copy(vectors%input_vec, vectors%result_vec, error=error)
+          CALL dbcsr_matrix_colvec_multiply(matrix(i)%matrix, input_vec, result_vec, 1.0_real_8, &
+                                            0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec)
+          swap_vec=>input_vec
+          input_vec=>result_vec
+          result_vec=>swap_vec
        END DO
 
-       CALL transfer_dbcsr_to_local_array_d(vectors%result_vec, w_vec, nrow_local, control%local_comp)
+       CALL transfer_dbcsr_to_local_array_d(input_vec, w_vec, nrow_local, control%local_comp)
 
        ! Let's do the orthonormalization, to get the new f_vec. First try the Gram Schmidt scheme
        CALL Gram_Schmidt_ortho_d(h_vec, ar_data%f_vec, s_vec, w_vec, nrow_local, j+1, &
-                               ar_data%local_history, ar_data%local_history, control%local_comp, control%pcol_group, error)
+                               ar_data%local_history, ar_data%local_history, control%local_comp, control%pcol_group)
 
        ! A bit more expensive but simpliy always top up with a DGKS correction, otherwise numerics
        ! can become a problem later on, there is probably a good check whether it's necessary, but we don't perform it
        CALL DGKS_ortho_d(h_vec, ar_data%f_vec, s_vec, nrow_local, j+1, ar_data%local_history, &
-                                   ar_data%local_history, control%local_comp, control%pcol_group, error)
+                                   ar_data%local_history, control%local_comp, control%pcol_group)
        ! Finally we can put the projections into our Hessenberg matrix
        ar_data%Hessenberg(1:j+1, j+1)= h_vec(1:j+1)
        control%current_step=j+1
@@ -323,7 +332,7 @@
     LOGICAL                                  :: is_local
     REAL(kind=real_8), DIMENSION(:), POINTER          :: data_vec
 
-    data_vec => dbcsr_get_data_p (vec%m%data_area, coersion=0.0_real_8)
+    data_vec => dbcsr_get_data_p (vec%m%data_area, select_data_type=0.0_real_8)
     IF(is_local)array(1:n)=data_vec(1:n)
 
   END SUBROUTINE transfer_dbcsr_to_local_array_d
@@ -342,7 +351,7 @@
     LOGICAL                                  :: is_local
     REAL(kind=real_8), DIMENSION(:), POINTER          :: data_vec
 
-    data_vec => dbcsr_get_data_p (vec%m%data_area, coersion=0.0_real_8)
+    data_vec => dbcsr_get_data_p (vec%m%data_area, select_data_type=0.0_real_8)
     IF(is_local)data_vec(1:n)=array(1:n)
 
 ! *****************************************************************************
@@ -361,21 +370,19 @@
 !> \param reorth_mat ...
 !> \param local_comp ...
 !> \param pcol_group ...
-!> \param error ...
 ! *****************************************************************************
   SUBROUTINE Gram_Schmidt_ortho_d(h_vec, f_vec, s_vec, w_vec, nrow_local,&
-                                            j, local_history, reorth_mat, local_comp, pcol_group, error)
+                                            j, local_history, reorth_mat, local_comp, pcol_group)
     REAL(kind=real_8), DIMENSION(:)      :: h_vec, s_vec, f_vec, w_vec
     REAL(kind=real_8), DIMENSION(:, :)    :: local_history, reorth_mat
     INTEGER                                          :: nrow_local, j, pcol_group
     LOGICAL                                          :: local_comp
-    TYPE(dbcsr_error_type), INTENT(inout)    :: error
 
     CHARACTER(LEN=*), PARAMETER :: routineN = 'Gram_Schmidt_ortho_d', &
          routineP = moduleN//':'//routineN
     INTEGER                                  :: handle
 
-    CALL dbcsr_error_set(routineN, handle, error)
+    CALL timeset(routineN, handle)
 
     ! Let's do the orthonormalization, first try the Gram Schmidt scheme
     h_vec=0.0_real_8; f_vec=0.0_real_8; s_vec=0.0_real_8
@@ -387,7 +394,7 @@
                                       nrow_local, h_vec, 1, 0.0_real_8, f_vec, 1)
     f_vec(:)=w_vec(:)-f_vec(:)
 
-    CALL dbcsr_error_stop(handle,error)
+    CALL timestop(handle)
 
   END SUBROUTINE Gram_Schmidt_ortho_d
 
@@ -402,14 +409,12 @@
 !> \param reorth_mat ...
 !> \param local_comp ...
 !> \param pcol_group ...
-!> \param error ...
 ! *****************************************************************************
   SUBROUTINE DGKS_ortho_d(h_vec, f_vec, s_vec, nrow_local, j, &
-                                    local_history, reorth_mat, local_comp, pcol_group, error)
+                                    local_history, reorth_mat, local_comp, pcol_group)
     REAL(kind=real_8), DIMENSION(:)      :: h_vec, s_vec, f_vec
     REAL(kind=real_8), DIMENSION(:, :)    :: local_history, reorth_mat
     INTEGER                                          :: nrow_local, j, pcol_group
-    TYPE(dbcsr_error_type), INTENT(inout)    :: error
 
     CHARACTER(LEN=*), PARAMETER :: routineN = 'DGKS_ortho_d', &
          routineP = moduleN//':'//routineN
@@ -417,7 +422,7 @@
     LOGICAL                                          :: local_comp
     INTEGER                                  :: handle
 
-    CALL dbcsr_error_set(routineN, handle, error)
+    CALL timeset(routineN, handle)
 
     IF(local_comp)CALL dgemv('T', nrow_local, j, 1.0_real_8, local_history, &
                                        nrow_local, f_vec, 1, 0.0_real_8, s_vec, 1)
@@ -426,7 +431,7 @@
                                        nrow_local, s_vec, 1, 1.0_real_8, f_vec, 1)
     h_vec(1:j)=h_vec(1:j)+s_vec(1:j)
 
-    CALL dbcsr_error_stop(handle,error)
+    CALL timestop(handle)
 
   END SUBROUTINE DGKS_ortho_d
 
@@ -459,15 +464,13 @@
 !> \param matrix_arnoldi ...
 !> \param vectors ...
 !> \param arnoldi_data ...
-!> \param error ...
 ! *****************************************************************************
 
-  SUBROUTINE gev_arnoldi_init_d (matrix, matrix_arnoldi, vectors, arnoldi_data, error)
+  SUBROUTINE gev_arnoldi_init_d (matrix, matrix_arnoldi, vectors, arnoldi_data)
     TYPE(dbcsr_obj_type_p), DIMENSION(:)     :: matrix
     TYPE(dbcsr_obj_type_p), DIMENSION(:)     :: matrix_arnoldi
     TYPE(m_x_v_vectors)                      :: vectors
     TYPE(dbcsr_arnoldi_data)                 :: arnoldi_data
-    TYPE(dbcsr_error_type), INTENT(inout)    :: error
 
     CHARACTER(LEN=*), PARAMETER :: routineN = 'arnoldi_init_d', &
       routineP = moduleN//':'//routineN
@@ -517,10 +520,11 @@
     ! compute the vector norm of the reandom vectorm, get it real valued as well (rnorm)
     CALL compute_norms_d(v_vec, norm, rnorm, control%pcol_group)
 
-    CALL dbcsr_scale(vectors%input_vec, REAL(1.0, real_8)/rnorm, error=error)
+    IF (rnorm==0) rnorm=1 ! catch case where this rank has no actual data
+    CALL dbcsr_scale(vectors%input_vec, REAL(1.0, real_8)/rnorm)
 
     CALL dbcsr_matrix_colvec_multiply(matrix(1)%matrix, vectors%input_vec, vectors%result_vec, 1.0_real_8, &
-                                      0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec, error)
+                                      0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec)
 
     CALL transfer_dbcsr_to_local_array_d(vectors%result_vec, w_vec, nrow_local, control%local_comp)
    
@@ -529,7 +533,7 @@
     CALL mp_sum(ar_data%rho_scale, pcol_group)
 
     CALL dbcsr_matrix_colvec_multiply(matrix(2)%matrix, vectors%input_vec, vectors%result_vec, 1.0_real_8, &
-                                      0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec, error)
+                                      0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec)
 
     CALL transfer_dbcsr_to_local_array_d(vectors%result_vec, w_vec, nrow_local, control%local_comp)
     
@@ -540,8 +544,8 @@
     CALL mp_bcast(ar_data%rho_scale,0,control%mp_group)
 
     ! if the maximum ev is requested we need to optimize with -A-rho*B
-    CALL dbcsr_copy(matrix_arnoldi(1)%matrix,matrix(1)%matrix,error=error)
-    CALL dbcsr_add(matrix_arnoldi(1)%matrix, matrix(2)%matrix, 1.0_real_8, -ar_data%rho_scale, error)
+    CALL dbcsr_copy(matrix_arnoldi(1)%matrix,matrix(1)%matrix)
+    CALL dbcsr_add(matrix_arnoldi(1)%matrix, matrix(2)%matrix, 1.0_real_8, -ar_data%rho_scale)
    
     ar_data%x_vec=v_vec
 
@@ -555,14 +559,12 @@
 !> \param matrix ...
 !> \param vectors ...
 !> \param arnoldi_data ...
-!> \param error ...
 ! *****************************************************************************
 
-  SUBROUTINE gev_build_subspace_d(matrix, vectors, arnoldi_data, error) 
+  SUBROUTINE gev_build_subspace_d(matrix, vectors, arnoldi_data)
     TYPE(dbcsr_obj_type_p), DIMENSION(:)     :: matrix
     TYPE(m_x_v_vectors)                      :: vectors
     TYPE(dbcsr_arnoldi_data)                 :: arnoldi_data
-    TYPE(dbcsr_error_type), INTENT(inout)    :: error
 
     CHARACTER(LEN=*), PARAMETER :: routineN = 'build_subspace_d', &
          routineP = moduleN//':'//routineN
@@ -589,7 +591,7 @@
 
     CALL transfer_local_array_to_dbcsr_d(vectors%input_vec, ar_data%x_vec, nrow_local, control%local_comp)
     CALL dbcsr_matrix_colvec_multiply(matrix(2)%matrix, vectors%input_vec, vectors%result_vec, 1.0_real_8, &
-                                      0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec, error)
+                                      0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec)
     CALL transfer_dbcsr_to_local_array_d(vectors%result_vec, BZmat(:,1), nrow_local, control%local_comp)
     
     norm=0.0_real_8 
@@ -603,22 +605,22 @@
        control%current_step=j
        CALL transfer_local_array_to_dbcsr_d(vectors%input_vec, Zmat(:,j), nrow_local, control%local_comp)
        CALL dbcsr_matrix_colvec_multiply(matrix(1)%matrix, vectors%input_vec, vectors%result_vec, 1.0_real_8, &
-                                        0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec, error)
+                                        0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec)
        CALL transfer_dbcsr_to_local_array_d(vectors%result_vec, CZmat(:,j), nrow_local, control%local_comp)
        w_vec(:)=CZmat(:,j)                         
        
        ! Let's do the orthonormalization, to get the new f_vec. First try the Gram Schmidt scheme
        CALL Gram_Schmidt_ortho_d(h_vec, ar_data%f_vec, s_vec, w_vec, nrow_local, j, &
-                               BZmat, Zmat, control%local_comp, control%pcol_group, error)
+                               BZmat, Zmat, control%local_comp, control%pcol_group)
 
        ! A bit more expensive but simpliy always top up with a DGKS correction, otherwise numerics
        ! can becom a problem later on, there is probably a good check, but we don't perform it
        CALL DGKS_ortho_d(h_vec, ar_data%f_vec, s_vec, nrow_local, j, BZmat, &
-                                    Zmat, control%local_comp, control%pcol_group, error)
+                                    Zmat, control%local_comp, control%pcol_group)
     
        CALL transfer_local_array_to_dbcsr_d(vectors%input_vec, ar_data%f_vec, nrow_local, control%local_comp)
        CALL dbcsr_matrix_colvec_multiply(matrix(2)%matrix, vectors%input_vec, vectors%result_vec, 1.0_real_8, &
-                                        0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec, error)
+                                        0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec)
        CALL transfer_dbcsr_to_local_array_d(vectors%result_vec, v_vec, nrow_local, control%local_comp)
        norm=0.0_real_8
        norm=DOT_PRODUCT(ar_data%f_vec,v_vec)
@@ -664,22 +666,20 @@
 !> \param matrix_arnoldi ...
 !> \param vectors ...
 !> \param arnoldi_data ...
-!> \param error ...
 ! *****************************************************************************
 
-  SUBROUTINE gev_update_data_d(matrix, matrix_arnoldi, vectors, arnoldi_data, error)
+  SUBROUTINE gev_update_data_d(matrix, matrix_arnoldi, vectors, arnoldi_data)
     TYPE(dbcsr_obj_type_p), DIMENSION(:)     :: matrix
     TYPE(dbcsr_obj_type_p), DIMENSION(:)     :: matrix_arnoldi
     TYPE(m_x_v_vectors)                      :: vectors
     TYPE(dbcsr_arnoldi_data)                 :: arnoldi_data
-    TYPE(dbcsr_error_type), INTENT(inout)    :: error
 
     CHARACTER(LEN=*), PARAMETER :: routineN = 'gev_update_data_d', &
       routineP = moduleN//':'//routineN
 
     TYPE(arnoldi_control), POINTER           :: control
     TYPE(arnoldi_data_d), POINTER            :: ar_data
-    INTEGER                                  :: nrow_local, ind, i
+    INTEGER                                  :: ncol_local, nrow_local, ind, i
     REAL(kind=real_8), ALLOCATABLE, DIMENSION(:)      :: v_vec
     REAL(real_8)                        :: rnorm
     REAL(kind=real_8)                         :: norm
@@ -702,22 +702,27 @@
 !                        ar_data%revec(1:control%current_step,control%selected_ind(1)))
 
 ! update the C-matrix (A-rho*B), if teh maximum value is requested we have to use -A-rho*B
-    CALL dbcsr_copy(matrix_arnoldi(1)%matrix,matrix(1)%matrix,error=error)
-    CALL dbcsr_add(matrix_arnoldi(1)%matrix, matrix(2)%matrix, 1.0_real_8, -ar_data%rho_scale, error)
+    CALL dbcsr_copy(matrix_arnoldi(1)%matrix,matrix(1)%matrix)
+    CALL dbcsr_add(matrix_arnoldi(1)%matrix, matrix(2)%matrix, 1.0_real_8, -ar_data%rho_scale)
 
 ! compute convergence and set the correct eigenvalue and eigenvector
-    CALL dbcsr_get_info(matrix=vectors%input_vec, nfullrows_local=nrow_local)
-    ALLOCATE(v_vec(nrow_local))
-    CALL compute_norms_d(ar_data%x_vec, norm, rnorm, control%pcol_group)
-    v_vec(:)=ar_data%x_vec(:)/rnorm
+    CALL dbcsr_get_info(matrix=vectors%input_vec, nfullrows_local=nrow_local, nfullcols_local=ncol_local)
+    IF (ncol_local>0) THEN
+       ALLOCATE(v_vec(nrow_local))
+       CALL compute_norms_d(ar_data%x_vec, norm, rnorm, control%pcol_group)
+       v_vec(:)=ar_data%x_vec(:)/rnorm
+    ENDIF
     CALL transfer_local_array_to_dbcsr_d(vectors%input_vec, v_vec, nrow_local, control%local_comp)
     CALL dbcsr_matrix_colvec_multiply(matrix_arnoldi(1)%matrix, vectors%input_vec, vectors%result_vec, 1.0_real_8, &
-                                            0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec, error)
-    CALL transfer_dbcsr_to_local_array_d(vectors%result_vec, v_vec, nrow_local, control%local_comp)                              
-    CALL compute_norms_d(v_vec, norm, rnorm, control%pcol_group)
-
-! check convergence and broadcast the real eigenvalue    
-    control%converged=rnorm.LT.control%threshold
+                                            0.0_real_8, vectors%rep_row_vec, vectors%rep_col_vec)
+    CALL transfer_dbcsr_to_local_array_d(vectors%result_vec, v_vec, nrow_local, control%local_comp)
+    IF (ncol_local>0) THEN
+       CALL compute_norms_d(v_vec, norm, rnorm, control%pcol_group)
+       ! check convergence 
+       control%converged=rnorm.LT.control%threshold
+       DEALLOCATE(v_vec)
+    ENDIF
+    ! and broadcast the real eigenvalue    
     CALL mp_bcast(control%converged,0,control%mp_group)
     ind=control%selected_ind(1)
     CALL mp_bcast(ar_data%rho_scale,0,control%mp_group)
@@ -725,7 +730,6 @@
 ! Again the maximum value request is done on -A therefore the eigenvalue needs the opposite sign
     ar_data%evals(ind)=ar_data%rho_scale
 
-    DEALLOCATE(v_vec)
 
   END SUBROUTINE gev_update_data_d
 
