@@ -1,6 +1,6 @@
 !-----------------------------------------------------------------------------!
 !   CP2K: A general program to perform molecular dynamics simulations         !
-!   Copyright (C) 2000 - 2014  CP2K developers group                          !
+!   Copyright (C) 2000 - 2015  CP2K developers group                          !
 !-----------------------------------------------------------------------------!
 
 ! *****************************************************************************
@@ -23,8 +23,6 @@
     LOGICAL, INTENT(OUT)                     :: found
     INTEGER, INTENT(OUT), OPTIONAL           :: row_size, col_size
 
-    TYPE(dbcsr_error_type)                   :: error
-
     CHARACTER(len=*), PARAMETER :: routineN = 'dbcsr_get_2d_block_p_c', &
       routineP = moduleN//':'//routineN
 
@@ -38,11 +36,11 @@
     LOGICAL                                  :: stored_tr
     COMPLEX(kind=real_4), DIMENSION(1,1), TARGET, SAVE    :: block0
 !   ---------------------------------------------------------------------------
-    IF (careful_mod) CALL dbcsr_error_set (routineN, error_handle, error=error)
+    IF (careful_mod) CALL timeset (routineN, error_handle)
     IF (debug_mod) THEN
        CALL dbcsr_assert (matrix%m%data_type, "EQ", dbcsr_type_complex_4,&
             dbcsr_fatal_level, dbcsr_caller_error,&
-            routineN, "Data type mismatch for requested block.",__LINE__,error)
+            routineN, "Data type mismatch for requested block.",__LINE__)
     ENDIF
 
     CALL dbcsr_get_block_index (matrix, row, col, stored_row, stored_col,&
@@ -63,21 +61,18 @@
        ELSE
           block_1d => pointer_view (dbcsr_get_data_p (&
                matrix%m%data_area, CMPLX(0.0, 0.0, real_4)), offset, offset+nze-1)
-          CALL dbcsr_set_block_pointer (matrix, block, stored_row, stored_col,&
-               rsize, csize, stored_tr, offset, buffer_tr=stored_tr,&
-               contiguous_pointers=.TRUE., error=error)
+          CALL dbcsr_set_block_pointer (matrix, block, rsize, csize, offset)
        ENDIF
     ELSEIF (ASSOCIATED (matrix%m%wms)) THEN
        nwms = SIZE(matrix%m%wms)
        iw = 1
 !$     CALL dbcsr_assert (nwms, "GE", omp_get_num_threads(),&
 !$        dbcsr_fatal_level, dbcsr_internal_error,&
-!$        routineN, "Number of work matrices not equal to number of threads", &
-!$        __LINE__, error=error)
+!$        routineN, "Number of work matrices not equal to number of threads", __LINE__)
 !$     iw = omp_get_thread_num () + 1
        CALL dbcsr_assert (dbcsr_use_mutable (matrix%m), dbcsr_failure_level,&
             dbcsr_caller_error, routineN,&
-            "Can not retrieve blocks from non-mutable work matrices.",__LINE__,error)
+            "Can not retrieve blocks from non-mutable work matrices.",__LINE__)
        IF (dbcsr_use_mutable (matrix%m)) THEN
           IF (.NOT. dbcsr_mutable_instantiated(matrix%m%wms(iw)%mutable)) THEN
              CALL dbcsr_mutable_new(matrix%m%wms(iw)%mutable,&
@@ -92,7 +87,7 @@
           ENDIF
        ENDIF
     ENDIF
-    IF (careful_mod) CALL dbcsr_error_stop (error_handle, error=error)
+    IF (careful_mod) CALL timestop (error_handle)
   END SUBROUTINE dbcsr_get_2d_block_p_c
 
 
@@ -115,7 +110,6 @@
     LOGICAL, INTENT(OUT)                     :: tr
     LOGICAL, INTENT(OUT)                     :: found
     INTEGER, INTENT(OUT), OPTIONAL           :: row_size, col_size
-    TYPE(dbcsr_error_type)                   :: error
 
     CHARACTER(len=*), PARAMETER :: routineN = 'dbcsr_get_block_p_c', &
       routineP = moduleN//':'//routineN
@@ -131,7 +125,7 @@
     IF (debug_mod) THEN
        CALL dbcsr_assert (matrix%m%data_type, "EQ", dbcsr_type_complex_4,&
             dbcsr_fatal_level, dbcsr_caller_error,&
-            routineN, "Data type mismatch for requested block.",__LINE__,error)
+            routineN, "Data type mismatch for requested block.",__LINE__)
     ENDIF
 
     CALL dbcsr_get_block_index (matrix, row, col, stored_row, stored_col,&
@@ -153,10 +147,10 @@
     ELSEIF (ASSOCIATED (matrix%m%wms)) THEN
        CALL dbcsr_assert (dbcsr_use_mutable (matrix%m), dbcsr_failure_level,&
             dbcsr_caller_error, routineN,&
-            "Can not retrieve blocks from non-mutable work matrices.",__LINE__,error)
+            "Can not retrieve blocks from non-mutable work matrices.",__LINE__)
        CALL dbcsr_assert ("NOT", dbcsr_use_mutable (matrix%m), dbcsr_failure_level,&
             dbcsr_caller_error, routineN,&
-            "Can not retrieve rank-1 block pointers from mutable work matrices.",__LINE__,error)
+            "Can not retrieve rank-1 block pointers from mutable work matrices.",__LINE__)
     ENDIF
   END SUBROUTINE dbcsr_get_block_p_c
 
@@ -188,7 +182,6 @@
     INTEGER, DIMENSION(:), POINTER           :: col_blk_size, row_blk_size
     LOGICAL                                  :: found, gift, tr, sym_tr
     COMPLEX(kind=real_4), DIMENSION(:,:), POINTER         :: original_block
-    TYPE(dbcsr_error_type)                   :: error
 
 !   ---------------------------------------------------------------------------
 
@@ -210,11 +203,9 @@
        tr = .FALSE.
     ENDIF
     sym_tr = .FALSE.
-    CALL dbcsr_get_stored_coordinates (matrix, stored_row, stored_col, sym_tr)
-    !call cp_assert (associated (matrix%m%wms), cp_fatal_level,&
-    !     cp_caller_error, routineN, "Work matrices not prepared")
+    CALL dbcsr_get_stored_coordinates (matrix, stored_row, stored_col)
     IF (.NOT.ASSOCIATED (matrix%m%wms)) THEN
-       CALL dbcsr_work_create (matrix, work_mutable=.TRUE., error=error)
+       CALL dbcsr_work_create (matrix, work_mutable=.TRUE.)
        !$OMP MASTER
        matrix%m%valid = .FALSE.
        !$OMP END MASTER
@@ -235,7 +226,7 @@
 !$  CALL dbcsr_assert (nwms, "GE", omp_get_num_threads(),&
 !$     dbcsr_fatal_level, dbcsr_internal_error,&
 !$     routineN, "Number of work matrices not equal to number of threads", &
-!$     __LINE__, error=error)
+!$     __LINE__)
 !$  iw = omp_get_thread_num () + 1
     CALL btree_add_c (matrix%m%wms(iw)%mutable%m%btree_c,&
          make_coordinate_tuple(stored_row, stored_col),&
@@ -253,9 +244,6 @@
        ELSE
           DEALLOCATE (original_block)
        ENDIF
-       !CALL cp_assert (ASSOCIATED (data_block%p), cp_warning_level,&
-       !     cp_internal_error, routineN,&
-       !     "Existing block has no associated pointer.")
        block => data_block2%p
     ENDIF
     IF (PRESENT (existed)) existed = found
@@ -337,7 +325,6 @@
     LOGICAL                                  :: found, tr, do_sum, tr_diff,&
                                                 sym_tr
     COMPLEX(kind=real_4), DIMENSION(:), POINTER           :: block_1d
-    TYPE(dbcsr_error_type)                   :: error
 
 !   ---------------------------------------------------------------------------
     IF (PRESENT (transposed)) THEN
@@ -355,12 +342,12 @@
     IF (tr) CALL swap (row_size, col_size)
 
     stored_row = row ; stored_col = col; sym_tr = .FALSE.
-    CALL dbcsr_get_stored_coordinates (matrix%m, stored_row, stored_col, sym_tr)
+    CALL dbcsr_get_stored_coordinates (matrix%m, stored_row, stored_col)
     nze = row_size*col_size
     !
     IF (debug_mod) THEN
        CALL dbcsr_assert (SIZE(block), "GE", nze, dbcsr_fatal_level,&
-            dbcsr_caller_error, routineN, "Invalid block dimensions",__LINE__,error)
+            dbcsr_caller_error, routineN, "Invalid block dimensions",__LINE__)
     ENDIF
     CALL dbcsr_get_stored_block_info (matrix%m, stored_row, stored_col,&
          found, blk, offset)
@@ -403,24 +390,23 @@
        !     cp_caller_error, routineN, "Work matrices not prepared")
        IF (.NOT.ASSOCIATED (matrix%m%wms)) THEN
           CALL dbcsr_work_create (matrix, nblks_guess=1,&
-               sizedata_guess=SIZE(block),error=error)
+               sizedata_guess=SIZE(block))
        ENDIF
        nwms = SIZE(matrix%m%wms)
        iw = 1
 !$     IF (debug_mod) THEN
 !$     CALL dbcsr_assert (nwms, "GE", omp_get_num_threads(),&
 !$        dbcsr_fatal_level, dbcsr_internal_error,&
-!$        routineN, "Number of work matrices not equal to number of threads", &
-!$        __LINE__, error=error)
+!$        routineN, "Number of work matrices not equal to number of threads", __LINE__)
 !$     ENDIF
 !$     iw = omp_get_thread_num () + 1
        blk_p = matrix%m%wms(iw)%datasize + 1
        IF (.NOT.dbcsr_wm_use_mutable (matrix%m%wms(iw))) THEN
           IF (tr) blk_p = -blk_p
-          CALL add_work_coordinate (matrix%m%wms(iw), row, col, blk_p, error=error)
+          CALL add_work_coordinate (matrix%m%wms(iw), row, col, blk_p)
           CALL dbcsr_data_ensure_size (matrix%m%wms(iw)%data_area,&
                matrix%m%wms(iw)%datasize+SIZE(block),&
-               factor=default_resize_factor, error=error)
+               factor=default_resize_factor)
           IF (PRESENT (scale)) THEN
              CALL dbcsr_data_set (matrix%m%wms(iw)%data_area, ABS(blk_p),&
                   data_size=SIZE(block), src=scale*block, source_lb=1)
@@ -446,9 +432,8 @@
                   make_coordinate_tuple(stored_row, stored_col),&
                   data_block, found, data_block2, replace=.TRUE.)
              IF (found) THEN
-                CALL dbcsr_assert (ASSOCIATED (data_block2%p), dbcsr_warning_level,&
-                     dbcsr_internal_error, routineN,&
-                     "Data was not present in block",__LINE__,error)
+                IF(.NOT.ASSOCIATED(data_block2%p))&
+                   CPWARN("Data was not present in block")
                 IF (ASSOCIATED (data_block2%p)) DEALLOCATE (data_block2%p)
              ENDIF
           ELSE
@@ -456,12 +441,12 @@
                   matrix%m%wms(iw)%mutable%m%btree_c,&
                   make_coordinate_tuple(stored_row, stored_col),&
                   data_block, found, data_block2, replace=.FALSE.)
-             IF (found .AND. nze .GT. 0) THEN
-                CALL caxpy (nze, CMPLX(1.0, 0.0, real_4), block(1), 1,&
-                     data_block2%p(1,1), 1)
-                CALL dbcsr_assert (ASSOCIATED (data_block%p), dbcsr_warning_level,&
-                     dbcsr_internal_error, routineN,&
-                     "Data was not present in block",__LINE__,error)
+             IF (found) THEN
+                IF(nze > 0) &
+                   CALL caxpy (nze, CMPLX(1.0, 0.0, real_4), block(1), 1,&
+                        data_block2%p(1,1), 1)
+                IF(.NOT.ASSOCIATED(data_block%p))&
+                   CPWARN("Data was not present in block")
                 IF (ASSOCIATED (data_block%p)) DEALLOCATE (data_block%p)
              ENDIF
           ENDIF
@@ -484,30 +469,16 @@
 !> \brief Sets a pointer, possibly using the buffers.
 !> \param[in] matrix           Matrix to use
 !> \param pointer_any The pointer to set
-!> \param row Row of block to point to
-!> \param col Column of block to point to
 !> \param rsize Row size of block to point to
 !> \param csize Column size of block to point to
-!> \param[in] main_tr          Whether block is transposed in the matrix
 !> \param[in] base_offset      The block pointer
-!> \param[in] buffer_tr        Whether buffer should be transposed
-!> \param[in] contiguous_pointers  (optional) Whether pointers should be made
-!>                                 contiguous
-!> \param[in] read_only        (optional) User promise not to change data
-!> \param[in,out] error        error
 ! *****************************************************************************
   SUBROUTINE dbcsr_set_block_pointer_2d_c (&
-       matrix, pointer_any, row, col,&
-       rsize, csize, main_tr, base_offset, buffer_tr, contiguous_pointers,&
-       read_only, error)
+       matrix, pointer_any, rsize, csize, base_offset)
     TYPE(dbcsr_obj), INTENT(IN)              :: matrix
     COMPLEX(kind=real_4), DIMENSION(:,:), POINTER         :: pointer_any
-    INTEGER, INTENT(IN)                      :: row, col, rsize, csize
-    LOGICAL, INTENT(IN)                      :: main_tr
+    INTEGER, INTENT(IN)                      :: rsize, csize
     INTEGER, INTENT(IN)                      :: base_offset
-    LOGICAL, INTENT(IN)                      :: buffer_tr
-    LOGICAL, INTENT(IN), OPTIONAL            :: contiguous_pointers, read_only
-    TYPE(dbcsr_error_type), INTENT(INOUT)    :: error
 
     CHARACTER(len=*), PARAMETER :: &
       routineN = 'dbcsr_set_block_pointer_2d_c', &
@@ -518,10 +489,10 @@
 
 !   ---------------------------------------------------------------------------
 
-    IF (careful_mod) CALL dbcsr_error_set (routineN, error_handler, error)
+    IF (careful_mod) CALL timeset (routineN, error_handler)
     CALL dbcsr_get_data (matrix%m%data_area, lin_blk_p,&
          lb=base_offset, ub=base_offset+rsize*csize-1)
     CALL pointer_rank_remap2 (pointer_any, rsize, csize,&
          lin_blk_p)
-    IF (careful_mod) CALL dbcsr_error_stop (error_handler, error)
+    IF (careful_mod) CALL timestop (error_handler)
   END SUBROUTINE dbcsr_set_block_pointer_2d_c
