@@ -1,6 +1,6 @@
 !-----------------------------------------------------------------------------!
 !   CP2K: A general program to perform molecular dynamics simulations         !
-!   Copyright (C) 2000 - 2014  CP2K developers group                          !
+!   Copyright (C) 2000 - 2015  CP2K developers group                          !
 !-----------------------------------------------------------------------------!
 
 ! *****************************************************************************
@@ -20,9 +20,9 @@
 
 !   ---------------------------------------------------------------------------
 
-    FORALL (i = 1 : d)
+    DO i = 1 , d
        block_data(i,i) = diagonal(i)
-    END FORALL
+    END DO
   END SUBROUTINE set_block2d_diagonal_z
 
 
@@ -41,9 +41,9 @@
 
 !   ---------------------------------------------------------------------------
 
-    FORALL (i = 1 : d)
+    DO i = 1 , d
        diagonal(i) = block_data(i, i)
-    END FORALL
+    END DO
   END SUBROUTINE get_block2d_diagonal_z
 
 
@@ -92,25 +92,33 @@
 ! Factors out the 4 combinations to remove branches from the inner loop.
 !  rs is the logical row size so it always remains the leading dimension.
     IF (.NOT. dst_tr .AND. .NOT. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_offset+dst_r_lb+row + (dst_c_lb+col-1)*dst_rs) &
                 = src(src_offset+src_r_lb+row+(src_c_lb+col-1)*src_rs)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (dst_tr .AND. .NOT. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_offset+dst_c_lb+col + (dst_r_lb+row-1)*dst_cs) &
               = src(src_offset+src_r_lb+row+(src_c_lb+col-1)*src_rs)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (.NOT. dst_tr .AND. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_offset+dst_r_lb+row + (dst_c_lb+col-1)*dst_rs) &
              = src(src_offset+src_c_lb+col+(src_r_lb+row-1)*src_cs)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (dst_tr .AND. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_offset+dst_c_lb+col + (dst_r_lb+row-1)*dst_cs)&
              = src(src_offset + src_c_lb+col+(src_r_lb+row-1)*src_cs)
-       END FORALL
+         END DO
+       END DO
     ENDIF
   END SUBROUTINE block_partial_copy_z
 
@@ -121,8 +129,6 @@
 !> \param dst_cs ...
 !> \param dst_tr ...
 !> \param src ...
-!> \param src_rs ...
-!> \param src_cs ...
 !> \param src_tr ...
 !> \param dst_r_lb ...
 !> \param dst_c_lb ...
@@ -134,7 +140,7 @@
 !> \note see block_partial_copy_a 
 ! *****************************************************************************
   SUBROUTINE block_partial_copy_1d2d_z(dst, dst_rs, dst_cs, dst_tr,&
-       src, src_rs, src_cs, src_tr,&
+       src, src_tr,&
        dst_r_lb, dst_c_lb, src_r_lb, src_c_lb, nrow, ncol,&
        dst_offset)
     COMPLEX(kind=real_8), DIMENSION(:), &
@@ -144,7 +150,6 @@
     LOGICAL                                  :: dst_tr
     COMPLEX(kind=real_8), DIMENSION(:,:), &
       INTENT(IN)                             :: src
-    INTEGER, INTENT(IN)                      :: src_rs, src_cs
     LOGICAL                                  :: src_tr
     INTEGER, INTENT(IN)                      :: dst_r_lb, dst_c_lb, src_r_lb, &
                                                 src_c_lb, nrow, ncol
@@ -157,31 +162,38 @@
 !   ---------------------------------------------------------------------------
 ! Factors out the 4 combinations to remove branches from the inner loop. rs is the logical row size so it always remains the leading dimension.
     IF (.NOT. dst_tr .AND. .NOT. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_offset+dst_r_lb+row + (dst_c_lb+col-1)*dst_rs) &
                 = src(src_r_lb+row, src_c_lb+col)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (dst_tr .AND. .NOT. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_offset+dst_c_lb+col + (dst_r_lb+row-1)*dst_cs) &
               = src(src_r_lb+row, src_c_lb+col)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (.NOT. dst_tr .AND. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_offset+dst_r_lb+row + (dst_c_lb+col-1)*dst_rs) &
              = src(src_c_lb+col, src_r_lb+row)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (dst_tr .AND. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_offset+dst_c_lb+col + (dst_r_lb+row-1)*dst_cs)&
              = src(src_c_lb+col, src_r_lb+row)
-       END FORALL
+         END DO
+       END DO
     ENDIF
   END SUBROUTINE block_partial_copy_1d2d_z
 ! *****************************************************************************
 !> \brief Copies a block subset
 !> \param dst ...
-!> \param dst_rs ...
 !> \param dst_cs ...
 !> \param dst_tr ...
 !> \param src ...
@@ -197,13 +209,12 @@
 !> \param src_offset ...
 !> \note see block_partial_copy_a
 ! *****************************************************************************
-  SUBROUTINE block_partial_copy_2d1d_z(dst, dst_rs, dst_cs, dst_tr,&
+  SUBROUTINE block_partial_copy_2d1d_z(dst, dst_tr,&
        src, src_rs, src_cs, src_tr,&
        dst_r_lb, dst_c_lb, src_r_lb, src_c_lb, nrow, ncol,&
        src_offset)
     COMPLEX(kind=real_8), DIMENSION(:,:), &
       INTENT(INOUT)                          :: dst
-    INTEGER, INTENT(IN)                      :: dst_rs, dst_cs
     INTEGER, INTENT(IN)                      :: src_offset
     LOGICAL                                  :: dst_tr
     COMPLEX(kind=real_8), DIMENSION(:), &
@@ -221,36 +232,40 @@
 !   ---------------------------------------------------------------------------
 ! Factors out the 4 combinations to remove branches from the inner loop. rs is the logical row size so it always remains the leading dimension.
     IF (.NOT. dst_tr .AND. .NOT. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_r_lb+row, dst_c_lb+col) &
                 = src(src_offset+src_r_lb+row+(src_c_lb+col-1)*src_rs)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (dst_tr .AND. .NOT. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_c_lb+col, dst_r_lb+row) &
               = src(src_offset+src_r_lb+row+(src_c_lb+col-1)*src_rs)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (.NOT. dst_tr .AND. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_r_lb+row, dst_c_lb+col) &
              = src(src_offset+src_c_lb+col+(src_r_lb+row-1)*src_cs)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (dst_tr .AND. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_c_lb+col, dst_r_lb+row)&
              = src(src_offset + src_c_lb+col+(src_r_lb+row-1)*src_cs)
-       END FORALL
+         END DO
+       END DO
     ENDIF
   END SUBROUTINE block_partial_copy_2d1d_z
 ! *****************************************************************************
 !> \brief Copies a block subset
 !> \param dst ...
-!> \param dst_rs ...
-!> \param dst_cs ...
 !> \param dst_tr ...
 !> \param src ...
-!> \param src_rs ...
-!> \param src_cs ...
 !> \param src_tr ...
 !> \param dst_r_lb ...
 !> \param dst_c_lb ...
@@ -260,16 +275,14 @@
 !> \param ncol ...
 !> \note see block_partial_copy_a
 ! *****************************************************************************
-  SUBROUTINE block_partial_copy_2d2d_z(dst, dst_rs, dst_cs, dst_tr,&
-       src, src_rs, src_cs, src_tr,&
+  SUBROUTINE block_partial_copy_2d2d_z(dst, dst_tr,&
+       src, src_tr,&
        dst_r_lb, dst_c_lb, src_r_lb, src_c_lb, nrow, ncol)
     COMPLEX(kind=real_8), DIMENSION(:,:), &
       INTENT(INOUT)                          :: dst
-    INTEGER, INTENT(IN)                      :: dst_rs, dst_cs
     LOGICAL                                  :: dst_tr
     COMPLEX(kind=real_8), DIMENSION(:,:), &
       INTENT(IN)                             :: src
-    INTEGER, INTENT(IN)                      :: src_rs, src_cs
     LOGICAL                                  :: src_tr
     INTEGER, INTENT(IN)                      :: dst_r_lb, dst_c_lb, src_r_lb, &
                                                 src_c_lb, nrow, ncol
@@ -282,25 +295,33 @@
 !   ---------------------------------------------------------------------------
 ! Factors out the 4 combinations to remove branches from the inner loop. rs is the logical row size so it always remains the leading dimension.
     IF (.NOT. dst_tr .AND. .NOT. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_r_lb+row, dst_c_lb+col) &
                 = src(src_r_lb+row, src_c_lb+col)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (dst_tr .AND. .NOT. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_c_lb+col, dst_r_lb+row) &
               = src(src_r_lb+row, src_c_lb+col)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (.NOT. dst_tr .AND. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_r_lb+row, dst_c_lb+col) &
              = src(src_c_lb+col, src_r_lb+row)
-       END FORALL
+         END DO
+       END DO
     ELSEIF (dst_tr .AND. src_tr) THEN
-       FORALL (col = 0:ncol-1, row=0:nrow-1)
+       DO col = 0,ncol-1
+         DO row = 0,nrow-1
           dst(dst_c_lb+col, dst_r_lb+row)&
              = src(src_c_lb+col, src_r_lb+row)
-       END FORALL
+         END DO
+       END DO
     ENDIF
   END SUBROUTINE block_partial_copy_2d2d_z
 
@@ -488,6 +509,7 @@
     INTEGER, INTENT(IN)                      :: rows, columns
     COMPLEX(kind=real_8), DIMENSION(rows*columns), &
       INTENT(INOUT)                          :: extent
+    COMPLEX(kind=real_8), DIMENSION(rows*columns)         :: extent_tr
 
     CHARACTER(len=*), PARAMETER :: routineN = 'block_transpose_inplace_z', &
       routineP = moduleN//':'//routineN
@@ -495,9 +517,16 @@
     INTEGER :: r, c
 !   ---------------------------------------------------------------------------
 
-    FORALL (r = 1:columns, c = 1:rows)
-       extent(r + (c-1)*columns) = extent(c + (r-1)*rows)
-    END FORALL
+    DO r = 1 , columns
+      DO c = 1 , rows
+       extent_tr(r + (c-1)*columns) = extent(c + (r-1)*rows)
+      END DO
+    END DO
+    DO r = 1 , columns
+      DO c = 1 , rows
+       extent(r + (c-1)*columns) = extent_tr(r + (c-1)*columns)
+      END DO
+    END DO
   END SUBROUTINE block_transpose_inplace_z
 
 
@@ -520,17 +549,16 @@
     CHARACTER(len=*), PARAMETER :: routineN = 'dbcsr_data_set_az', &
          routineP = moduleN//':'//routineN
     INTEGER                                  :: lb_s, ub, ub_s
-    TYPE(dbcsr_error_type)                   :: error
 !   ---------------------------------------------------------------------------
     IF (debug_mod) THEN
        CALL dbcsr_assert (ASSOCIATED (dst%d),&
             dbcsr_fatal_level, dbcsr_caller_error, routineN,&
-            "Target data area must be setup.",__LINE__,error)
+            "Target data area must be setup.",__LINE__)
        CALL dbcsr_assert (SIZE(src) .GE. data_size,&
             dbcsr_fatal_level, dbcsr_caller_error, routineN,&
-            "Not enough source data.",__LINE__,error)
+            "Not enough source data.",__LINE__)
        CALL dbcsr_assert (dst%d%data_type .EQ. dbcsr_type_complex_8, dbcsr_failure_level,&
-            dbcsr_caller_error, routineN, "Data type mismatch.",__LINE__,error)
+            dbcsr_caller_error, routineN, "Data type mismatch.",__LINE__)
     ENDIF
     ub = lb + data_size - 1
     IF (PRESENT (source_lb)) THEN
@@ -565,13 +593,13 @@
 !   ---------------------------------------------------------------------------
 
     IF(PRESENT(imin).AND.PRESENT(imax)) THEN
-       FORALL (i = MAX(1,imin):MIN(m,imax))
-          blk(i,i) = blk(i,i) + alpha
-       END FORALL
+       DO i = MAX(1,imin),MIN(m,imax)
+         blk(i,i) = blk(i,i) + alpha
+       ENDDO
     ELSE
-       FORALL (i = 1:m)
+       DO i = 1,m
           blk(i,i) = blk(i,i) + alpha
-       END FORALL
+       END DO
     ENDIF
   END SUBROUTINE block_2d_add_on_diag_z
 
