@@ -1,6 +1,6 @@
 !-----------------------------------------------------------------------------!
 !   CP2K: A general program to perform molecular dynamics simulations         !
-!   Copyright (C) 2000 - 2014  CP2K developers group                          !
+!   Copyright (C) 2000 - 2015  CP2K developers group                          !
 !-----------------------------------------------------------------------------!
 
 ! *****************************************************************************
@@ -8,13 +8,11 @@
 !>        type of the matrix.
 !> \param scalar ...
 !> \param matrix ...
-!> \param error ...
 !> \retval encapsulated ...
 ! *****************************************************************************
-  FUNCTION make_conformant_scalar_s (scalar, matrix, error) RESULT (encapsulated)
+  FUNCTION make_conformant_scalar_s (scalar, matrix) RESULT (encapsulated)
     REAL(kind=real_4), INTENT(IN)                      :: scalar
     TYPE(cp_dbcsr_type), INTENT(IN)          :: matrix
-    TYPE(cp_error_type), INTENT(INOUT)       :: error
 
     CHARACTER(len=*), PARAMETER :: routineN = 'make_conformant_scalar_s', &
       routineP = moduleN//':'//routineN
@@ -28,10 +26,8 @@
     scalar_data_type = dbcsr_scalar_get_type(encapsulated)
     IF (scalar_data_type .EQ. dbcsr_type_complex_4 .OR.&
         scalar_data_type .EQ. dbcsr_type_complex_8) THEN
-       CALL cp_assert (data_type .EQ. dbcsr_type_complex_4 .OR.&
-            data_type .EQ. dbcsr_type_complex_8,&
-            cp_fatal_level, cp_wrong_args_error, routineN,&
-            "Can not conform a complex to a real number", error=error)
+       IF(data_type .NE. dbcsr_type_complex_4 .AND. data_type .NE. dbcsr_type_complex_8)&
+          CPABORT("Can not conform a complex to a real number")
     END IF
     CALL dbcsr_scalar_set_type (encapsulated,data_type)
   END FUNCTION make_conformant_scalar_s
@@ -57,9 +53,6 @@
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_reserve_block2d_s', &
       routineP = moduleN//':'//routineN
 
-    TYPE(cp_error_type)                      :: error
-
-    CALL cp_error_init (error)
     CALL dbcsr_reserve_block2d(matrix%matrix, row, col, block,&
          transposed, existed)
 
@@ -96,8 +89,8 @@
     CALL dbcsr_iterator_next_block (iterator, row, column,&
        block, transposed,&
        block_number, row_size, col_size, row_offset, col_offset)
-    CALL cp_assert(.NOT. transposed, cp_fatal_level, cp_internal_error,&
-         routineN, "CP2K does not handle transposed blocks.")
+    IF(transposed)&
+       CPABORT("CP2K does not handle transposed blocks.")
 
   END SUBROUTINE cp_iterator_next_2d_block_s
 
@@ -130,8 +123,8 @@
 
     CALL dbcsr_iterator_next_block (iterator, row, column, block,&
        transposed, block_number, row_size, col_size, row_offset, col_offset)
-    CALL cp_assert(.NOT. transposed, cp_fatal_level, cp_internal_error,&
-         routineN, "CP2K does not handle transposed blocks.")
+    IF(transposed)&
+       CPABORT("CP2K does not handle transposed blocks.")
 
   END SUBROUTINE cp_iterator_next_1d_block_s
 
@@ -156,9 +149,6 @@
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_put_block2d_s', &
       routineP = moduleN//':'//routineN
 
-    TYPE(cp_error_type)                      :: error
-
-    CALL cp_error_init (error)
     CALL dbcsr_put_block(matrix%matrix, row, col, block,&
        summation=summation, scale=scale)
 
@@ -185,9 +175,6 @@
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_put_block_s', &
       routineP = moduleN//':'//routineN
 
-    TYPE(cp_error_type)                      :: error
-
-    CALL cp_error_init (error)
     CALL dbcsr_put_block(matrix%matrix, row, col, block,&
        summation=summation, scale=scale)
 
@@ -219,8 +206,8 @@
 
     CALL dbcsr_get_block_p(matrix%matrix,row,col,block,tr,found,&
          row_size, col_size)
-    CALL cp_assert(.NOT. tr, cp_fatal_level, cp_internal_error,&
-         routineN, "CP2K does not handle transposed blocks.")
+    IF(tr)&
+       CPABORT("CP2K does not handle transposed blocks.")
   END SUBROUTINE cp_dbcsr_get_2d_block_p_s
 
 
@@ -246,13 +233,11 @@
       routineP = moduleN//':'//routineN
 
     LOGICAL                                   :: tr
-    TYPE(cp_error_type)                       :: error
 
-    CALL cp_error_init (error)
     CALL dbcsr_get_block_p(matrix%matrix,row,col,block,tr,found,&
        row_size, col_size)
-    CALL cp_assert(.NOT. tr, cp_fatal_level, cp_internal_error,&
-         routineN, "CP2K does not handle transposed blocks.")
+    IF(tr)&
+       CPABORT("CP2K does not handle transposed blocks.")
 
   END SUBROUTINE cp_dbcsr_get_block_p_s
 
@@ -261,21 +246,18 @@
 !> \brief ...
 !> \param matrix_a ...
 !> \param trace ...
-!> \param error ...
 ! *****************************************************************************
-  SUBROUTINE cp_dbcsr_trace_a_s (matrix_a, trace, error)
+  SUBROUTINE cp_dbcsr_trace_a_s (matrix_a, trace)
     TYPE(cp_dbcsr_type), INTENT(INOUT)       :: matrix_a
     REAL(kind=real_4), INTENT(OUT)                     :: trace
-    TYPE(cp_error_type), INTENT(INOUT)       :: error
 
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_trace_a_s', &
       routineP = moduleN//':'//routineN
 
-    TYPE(dbcsr_error_type)                   :: dbcsr_error
     TYPE(dbcsr_scalar_type)                  :: trace_scalar
 
     trace_scalar = dbcsr_scalar_zero (cp_dbcsr_get_data_type(matrix_a))
-    CALL dbcsr_trace(matrix_a%matrix, trace_scalar, dbcsr_error)
+    CALL dbcsr_trace(matrix_a%matrix, trace_scalar)
     CALL dbcsr_scalar_fill_all (trace_scalar)
     CALL dbcsr_scalar_get_value (trace_scalar, trace)
   END SUBROUTINE cp_dbcsr_trace_a_s
@@ -289,21 +271,17 @@
 !> \param trans_a ...
 !> \param trans_b ...
 !> \param local_sum ...
-!> \param error ...
 ! *****************************************************************************
-  SUBROUTINE cp_dbcsr_trace_ab_s (matrix_a, matrix_b, trace, trans_a, trans_b, local_sum, error)
+  SUBROUTINE cp_dbcsr_trace_ab_s (matrix_a, matrix_b, trace, trans_a, trans_b, local_sum)
     TYPE(cp_dbcsr_type), INTENT(INOUT)       :: matrix_a, matrix_b
     REAL(kind=real_4), INTENT(INOUT)                   :: trace
     CHARACTER(LEN=*), INTENT(IN), OPTIONAL   :: trans_a, trans_b
     LOGICAL, INTENT(IN), OPTIONAL            :: local_sum
-    TYPE(cp_error_type), INTENT(INOUT)       :: error
 
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_trace_ab_s', &
       routineP = moduleN//':'//routineN
 
-    TYPE(dbcsr_error_type)                   :: dbcsr_error
-
-    CALL dbcsr_trace(matrix_a%matrix, matrix_b%matrix, trace, trans_a, trans_b, local_sum, dbcsr_error)
+    CALL dbcsr_trace(matrix_a%matrix, matrix_b%matrix, trace, trans_a, trans_b, local_sum)
   END SUBROUTINE cp_dbcsr_trace_ab_s
 
 
@@ -323,16 +301,17 @@
 !> \param first_k ...
 !> \param last_k ...
 !> \param retain_sparsity ...
+!> \param match_matrix_sizes Enables BLAS XGEMM-style multiplication
+!>        of matrices with incompatible dimensions. By default it's disabled.
 !> \param filter_eps ...
-!> \param error ...
 !> \param flop ...
 ! *****************************************************************************
   SUBROUTINE cp_dbcsr_multiply_s (transa, transb,&
        alpha, matrix_a, matrix_b, beta, matrix_c,&
        first_row, last_row, first_column, last_column, first_k, last_k,&
-       retain_sparsity, &
+       retain_sparsity, match_matrix_sizes, &
        filter_eps,&
-       error, flop)
+       flop)
     CHARACTER(LEN=1), INTENT(IN)             :: transa, transb
     REAL(kind=real_4), INTENT(IN)                      :: alpha
     TYPE(cp_dbcsr_type), INTENT(IN)          :: matrix_a, matrix_b
@@ -341,9 +320,8 @@
     INTEGER, INTENT(IN), OPTIONAL            :: first_row, last_row, &
                                                 first_column, last_column, &
                                                 first_k, last_k
-    LOGICAL, INTENT(IN), OPTIONAL            :: retain_sparsity
+    LOGICAL, INTENT(IN), OPTIONAL            :: retain_sparsity, match_matrix_sizes
     REAL(kind=real_8), INTENT(IN), OPTIONAL :: filter_eps
-    TYPE(cp_error_type), INTENT(INOUT)       :: error
     INTEGER(int_8), INTENT(OUT), OPTIONAL    :: flop
 
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_multiply_s', &
@@ -351,9 +329,8 @@
 
     CHARACTER(LEN=1)                         :: shape_a, shape_b, trans_a, &
                                                 trans_b
-    LOGICAL                                  :: new_a_is_new, new_b_is_new
+    LOGICAL                                  :: my_match_matrix_sizes
     TYPE(cp_dbcsr_type)                      :: new_a, new_b
-    TYPE(dbcsr_error_type)                   :: dbcsr_error
 
     trans_a = transa
     trans_b = transb
@@ -363,20 +340,28 @@
     IF(cp_dbcsr_nfullcols_total(matrix_a).EQ.cp_dbcsr_nfullrows_total(matrix_a)) shape_a='S'
     shape_b='R'
     IF(cp_dbcsr_nfullcols_total(matrix_b).EQ.cp_dbcsr_nfullrows_total(matrix_b)) shape_b='S'
-    CALL matrix_match_sizes (matrix_c, matrix_a, transa, matrix_b, transb,&
-         new_a, new_b, new_a_is_new, new_b_is_new, error)
+
+    my_match_matrix_sizes=.FALSE.
+    IF(PRESENT(match_matrix_sizes)) my_match_matrix_sizes=match_matrix_sizes
+    IF(my_match_matrix_sizes)THEN
+       CALL matrix_match_sizes (matrix_c, matrix_a, transa, matrix_b, transb, new_a, new_b)
+    ELSE
+       CALL cp_dbcsr_init(new_a)
+       CALL cp_dbcsr_init(new_b)
+       CALL cp_dbcsr_copy (new_a, matrix_a, shallow_data=.TRUE.)
+       CALL cp_dbcsr_copy (new_b, matrix_b, shallow_data=.TRUE.)
+    END IF
+
     CALL dbcsr_multiply(transa, transb,&
          alpha, new_a%matrix, new_b%matrix, beta, matrix_c%matrix,&
          first_row, last_row, first_column, last_column, first_k, last_k,&
          retain_sparsity, &
          filter_eps=filter_eps,&
-         error=dbcsr_error, flop=flop)
-    IF (new_a_is_new) THEN
-       CALL cp_dbcsr_release (new_a, error=error)
-    ENDIF
-    IF (new_b_is_new) THEN
-       CALL cp_dbcsr_release (new_b, error=error)
-    ENDIF
+         flop=flop)
+
+    CALL cp_dbcsr_release (new_a)
+    CALL cp_dbcsr_release (new_b)
+
   END SUBROUTINE cp_dbcsr_multiply_s
 
 
@@ -385,20 +370,16 @@
 !> \param matrix_a ...
 !> \param alpha ...
 !> \param side ...
-!> \param error ...
 ! *****************************************************************************
-  SUBROUTINE cp_dbcsr_scale_by_vector_s (matrix_a, alpha, side, error)
+  SUBROUTINE cp_dbcsr_scale_by_vector_s (matrix_a, alpha, side)
     TYPE(cp_dbcsr_type), INTENT(INOUT)        :: matrix_a
     REAL(kind=real_4), DIMENSION(:), INTENT(IN), TARGET :: alpha
     CHARACTER(LEN=*), INTENT(IN)              :: side
-    TYPE(cp_error_type), INTENT(INOUT)        :: error
 
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_scale_by_vector_s ', &
       routineP = moduleN//':'//routineN
 
-    TYPE(dbcsr_error_type)                    :: dbcsr_error
-
-    CALL dbcsr_scale_by_vector(matrix_a%matrix, alpha, side, dbcsr_error)
+    CALL dbcsr_scale_by_vector(matrix_a%matrix, alpha, side)
   END SUBROUTINE cp_dbcsr_scale_by_vector_s
 
 
@@ -407,20 +388,16 @@
 !> \param matrix_a ...
 !> \param alpha_scalar ...
 !> \param last_column ...
-!> \param error ...
 ! *****************************************************************************
-  SUBROUTINE cp_dbcsr_scale_s (matrix_a, alpha_scalar, last_column, error)
+  SUBROUTINE cp_dbcsr_scale_s (matrix_a, alpha_scalar, last_column)
     TYPE(cp_dbcsr_type), INTENT(INOUT)       :: matrix_a
     REAL(kind=real_4), INTENT(IN)                      :: alpha_scalar
     INTEGER, INTENT(IN), OPTIONAL            :: last_column
-    TYPE(cp_error_type), INTENT(INOUT)       :: error
 
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_scale_s', &
       routineP = moduleN//':'//routineN
 
-    TYPE(dbcsr_error_type)                   :: dbcsr_error
-
-    CALL dbcsr_scale(matrix_a%matrix, alpha_scalar, last_column, dbcsr_error)
+    CALL dbcsr_scale(matrix_a%matrix, alpha_scalar, last_column)
   END SUBROUTINE cp_dbcsr_scale_s
 
 
@@ -428,19 +405,15 @@
 !> \brief ...
 !> \param matrix ...
 !> \param alpha ...
-!> \param error ...
 ! *****************************************************************************
-  SUBROUTINE cp_dbcsr_set_s (matrix, alpha, error)
+  SUBROUTINE cp_dbcsr_set_s (matrix, alpha)
     TYPE(cp_dbcsr_type), INTENT(INOUT)       :: matrix
     REAL(kind=real_4), INTENT(IN)                      :: alpha
-    TYPE(cp_error_type), INTENT(INOUT)       :: error
 
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_set_s', &
       routineP = moduleN//':'//routineN
 
-    TYPE(dbcsr_error_type)                   :: dbcsr_error
-
-    CALL dbcsr_set(matrix%matrix, cp_dbcsr_conform_scalar (alpha, matrix, error), dbcsr_error)
+    CALL dbcsr_set(matrix%matrix, cp_dbcsr_conform_scalar (alpha, matrix))
   END SUBROUTINE cp_dbcsr_set_s
 
 
@@ -450,18 +423,35 @@
 !> \param matrix_b ...
 !> \param alpha_scalar ...
 !> \param beta_scalar ...
-!> \param error ...
 ! *****************************************************************************
-  SUBROUTINE cp_dbcsr_add_s (matrix_a, matrix_b, alpha_scalar, beta_scalar, error)
+  SUBROUTINE cp_dbcsr_add_s (matrix_a, matrix_b, alpha_scalar, beta_scalar)
     TYPE(cp_dbcsr_type), INTENT(INOUT)       :: matrix_a
     TYPE(cp_dbcsr_type), INTENT(IN)          :: matrix_b
     REAL(kind=real_4), INTENT(IN)                      :: alpha_scalar, beta_scalar
-    TYPE(cp_error_type), INTENT(INOUT)       :: error
 
     CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_add_s', &
       routineP = moduleN//':'//routineN
 
-    TYPE(dbcsr_error_type)                   :: dbcsr_error
-
-    CALL dbcsr_add(matrix_a%matrix, matrix_b%matrix, alpha_scalar, beta_scalar, dbcsr_error)
+    CALL dbcsr_add(matrix_a%matrix, matrix_b%matrix, alpha_scalar, beta_scalar)
   END SUBROUTINE cp_dbcsr_add_s
+
+! *****************************************************************************
+!> \brief ...
+!> \param matrix ...
+!> \param index_matrix ...
+!> \param lb ...
+!> \param ub ...
+!> \retval DATA ...
+! *****************************************************************************
+  FUNCTION cp_dbcsr_get_data_c_s (matrix, index_matrix, select_data_type, lb, ub) RESULT (DATA)
+    TYPE(cp_dbcsr_type), INTENT(IN)  :: matrix
+    INTEGER, INTENT(IN)              :: index_matrix
+    REAL(kind=real_4), INTENT(IN)              :: select_data_type
+    REAL(kind=real_4), DIMENSION(:), POINTER   :: DATA
+    INTEGER, INTENT(IN), OPTIONAL    :: lb, ub
+    
+    CHARACTER(len=*), PARAMETER :: routineN = 'cp_dbcsr_get_data_p_s', &
+      routineP = moduleN//':'//routineN
+
+    DATA => dbcsr_get_data_p(matrix%matrix%m%wms(index_matrix)%data_area,select_data_type,lb,ub)
+  END FUNCTION cp_dbcsr_get_data_c_s
