@@ -1,5 +1,10 @@
-#ifndef FFT_CUDA_UTILS_H
-#define FFT_CUDA_UTILS_H
+/*****************************************************************************
+ *  CP2K: A general program to perform molecular dynamics simulations        *
+ *  Copyright (C) 2000 - 2015  CP2K developers group                         *
+ *****************************************************************************/
+
+#ifndef PW_CUDA_UTILS_H
+#define PW_CUDA_UTILS_H
 
 extern void pw_cuda_error_check (cudaError_t cudaError, int line);
 
@@ -22,7 +27,7 @@ extern void pw_cuda_device_mem_free (float **ptr);
 extern void pw_cuda_device_mem_free (double **ptr);
 
 // DEVICE INIT/RELEASE
-extern "C" void pw_cuda_device_mem_init (int memory);
-extern "C" void pw_cuda_device_mem_release ();
+extern "C" int  pw_cuda_init ();
+extern "C" void pw_cuda_release ();
 
 #endif
